@@ -55,12 +55,13 @@ within the XAS enviornment.
 
 =head1 CONFIGURATION
 
+Place your configuration informaion here.
 
 =head1 SEE ALSO
 
  sbin/daemon-template.pl
 
- XAS
+L<XAS|XAS>
 
 =head1 AUTHOR
 
