@@ -32,7 +32,7 @@ L<Badger::Utils|Badger::Utils>.
 
 =head1 SEE ALSO
 
- XAS
+L<XAS|XAS>
 
 =head1 AUTHOR
 
