@@ -183,7 +183,7 @@ Returns a list of queues that will be listened on.
 
 =head1 SEE ALSO
 
- XAS
+L<XAS|XAS>
 
 =head1 AUTHOR
 
