@@ -84,7 +84,7 @@ that the process has forked.
 
 =head1 SEE ALSO
 
- XAS
+L<XAS|XAS>
 
 =head1 AUTHOR
 
