@@ -106,7 +106,7 @@ Returns the function the worker performs.
  Gearman::XS::Client
  Gearman::XS::Worker
 
- XAS
+L<XAS|XAS>
 
 =head1 AUTHOR
 
